@@ -400,7 +400,7 @@ implements ControlValueAccessor, OnInit, AfterViewInit, OnChanges {
         }, {});
         
         document.querySelectorAll('ngb-typeahead-window button[disabled]').forEach(b => b.setAttribute('tabindex', '-1'));
-        this.controller = this.instance['_elementRef'].nativeElement as HTMLInputElement;
+        this.controller = this.instance['_nativeElement'] as HTMLInputElement;
         this.controller.addEventListener('keydown', this.onKeydown.bind(this));
     }
 
@@ -749,7 +749,7 @@ implements ControlValueAccessor, OnInit, AfterViewInit, OnChanges {
 
     filter = (text$: Observable<string>): Observable<ComboboxEntry[]> => {
         return text$.pipe(
-            // eslint-disable-next-line no-magic-numbers
+             
             debounceTime(200),
             distinctUntilChanged(),
 
