@@ -1,6 +1,6 @@
 import {Component, OnInit, ViewChild, Input, Renderer2,
     Output, EventEmitter, ViewChildren, QueryList, PipeTransform, Pipe} from '@angular/core';
-import {tap} from 'rxjs/operators';
+import {tap} from 'rxjs';
 import {IdlService, IdlObject} from '@eg/core/idl.service';
 import {OrgService} from '@eg/core/org.service';
 import {AuthService} from '@eg/core/auth.service';
@@ -60,8 +60,8 @@ export class VolEditComponent implements OnInit {
     // Set default for Call Number Label requirement
     requireCNL = true;
 
-    // For every org we are editing copies for, whether they require parts to be on copies if the record has parts
-    requirePartsOrgMap : {[key: number]: boolean} = {};
+    // For every copy in the context, whether or not the copy will need a part
+    @Input() itemRequirePartsMap : {[key: number]: boolean} = {};
 
     // When adding multiple vols via add-many popover.
     addVolCount: number = null;
@@ -98,14 +98,6 @@ export class VolEditComponent implements OnInit {
 
         this.volcopy.genBarcodesRequested.subscribe(() => this.generateBarcodes());
 
-        // Check for each org if a part is required
-        for (const orgId of this.context.getOwningLibIds()) {
-            this.org.settings('circ.holds.ui_require_monographic_part_when_present', orgId)
-                .then(settings => {
-                    this.requirePartsOrgMap[orgId] = Boolean(settings['circ.holds.ui_require_monographic_part_when_present']);
-                });
-        }
-
         // Check to see if call number label is required
         this.org.settings('cat.require_call_number_labels')
             .then(settings => {
@@ -131,22 +123,6 @@ export class VolEditComponent implements OnInit {
         return '';
     }
 
-    recordHasParts(bibId: number): boolean {
-        return this.volcopy.bibParts[bibId] &&
-            this.volcopy.bibParts[bibId].length > 0;
-    }
-
-    copyRequiresParts(node: HoldingsTreeNode) : boolean {
-        if (['org', 'vol'].includes(node.nodeType)){
-            throw new TypeError('Invalid HoldingsTreeNode type!');
-        }
-
-        const org = node.parentNode.target.owning_lib();
-        const record = node.parentNode.target.record();
-
-        return this.recordHasParts(record) && this.requirePartsOrgMap[org];
-    }
-
     // Column width (flex:x) for column by column number.
     flexAt(column: number): number {
         if (!this.displayColumn(this.flexColMap[column])) {
@@ -278,13 +254,6 @@ export class VolEditComponent implements OnInit {
 
     applyCopyValue(copy: IdlObject, key: string, value: any) {
         if (copy[key]() !== value) {
-            // If the field is number-ish, the empty string means null. Force that here.
-            // ??? Should all fields be forced to null on empty string?
-            if (value === '' &&
-                ['float','int','number','money'].includes(this.idl.classes.acp.field_map[key]?.datatype)
-            ) {
-                value = null;
-            }
             copy[key](value);
             copy.ischanged(true);
         }
@@ -325,7 +294,6 @@ export class VolEditComponent implements OnInit {
             copy.ischanged(true);
         }
 
-        this.emitSaveChange();
     }
 
     batchVolApply() {
@@ -468,11 +436,9 @@ export class VolEditComponent implements OnInit {
                 barcode: barcode,
                 id: {'!=': copy.id()}
             }).subscribe(
-                resp => {
+                { next: resp => {
                     if (resp) { copy._dupe_barcode = true; }
-                },
-                (err: unknown) => {},
-                () => this.emitSaveChange()
+                }, error: (err: unknown) => {}, complete: () => this.emitSaveChange() }
             );
         }
     }
@@ -641,8 +607,7 @@ export class VolEditComponent implements OnInit {
 
         const badCopies = copies.filter(copy => {
             if (copy._dupe_barcode ||
-                (!copy.isnew() && !copy.barcode()) ||
-                (this.copyRequiresParts(this.context.findOrCreateCopyNode(copy)) && (!copy.parts() || copy.parts().length === 0))
+                (!copy.isnew() && !copy.barcode())
             ) {
                 return true;
             } else {
