@@ -586,6 +586,15 @@ sub get_hold_copy_summary {
         $copy_count_meth .= '.staff';
     }
     my $req1 = $search->request($copy_count_meth, $org, $rec_id); 
+    $self->ctx->{copy_summary} = $req1->recv->content;
+    if ($ctx->{search_lasso}) {
+        my ($group_counts) = $search->request("$copy_count_meth.lasso", $org, $rec_id, $ctx->{search_lasso})->recv->content;
+        unshift @{$self->ctx->{copy_summary}}, $group_counts->[0];
+    }
+    my $total_item_method = 'open-ils.search.biblio.record.copy_total';
+    $total_item_method .= '.staff' if ($ctx->{is_staff});
+    my $lassos = $ctx->{search_lasso} ? [$ctx->{search_lasso}] : [];
+    $self->ctx->{total_copies} = $search->request($total_item_method, $rec_id, [$org], $self->ctx->{copy_depth}, $lassos)->recv->content;
 
     # if org unit hiding applies, limit the hold count to holds
     # whose pickup library is within our depth-scoped tree
@@ -599,8 +608,6 @@ sub get_hold_copy_summary {
         'open-ils.circ', 'open-ils.circ.bre.holds.count', 
         $rec_id, $count_args);
 
-    $self->ctx->{copy_summary} = $req1->recv->content;
-
     $search->kill_me;
 }
 
