@@ -111,7 +111,7 @@ CREATE INDEX cp_creator_idx  ON asset.copy ( creator );
 CREATE INDEX cp_editor_idx   ON asset.copy ( editor );
 CREATE INDEX cp_create_date  ON asset.copy (create_date);
 CREATE INDEX cp_extant_by_circ_lib_idx ON asset.copy(circ_lib) WHERE deleted = FALSE OR deleted IS FALSE;
-CREATE RULE protect_copy_delete AS ON DELETE TO asset.copy DO INSTEAD UPDATE asset.copy SET deleted = TRUE WHERE OLD.id = asset.copy.id;
+CREATE RULE protect_copy_delete AS ON DELETE TO asset.copy DO INSTEAD UPDATE asset.copy SET deleted = TRUE WHERE OLD.id = asset.copy.id RETURNING *;
 
 CREATE TABLE asset.copy_part_map (
     id          SERIAL  PRIMARY KEY,
@@ -500,8 +500,11 @@ CREATE INDEX asset_call_number_upper_label_id_owning_lib_idx ON asset.call_numbe
 CREATE INDEX asset_call_number_label_sortkey ON asset.call_number(oils_text_as_bytea(label_sortkey));
 CREATE UNIQUE INDEX asset_call_number_label_once_per_lib ON asset.call_number (record, owning_lib, label, prefix, suffix) WHERE deleted = FALSE OR deleted IS FALSE;
 CREATE INDEX asset_call_number_label_sortkey_browse ON asset.call_number(oils_text_as_bytea(label_sortkey), oils_text_as_bytea(label), id, owning_lib) WHERE deleted IS FALSE OR deleted = FALSE;
-CREATE RULE protect_cn_delete AS ON DELETE TO asset.call_number DO INSTEAD UPDATE asset.call_number SET deleted = TRUE WHERE OLD.id = asset.call_number.id;
-CREATE RULE protect_acn_id_neg1 AS ON UPDATE TO asset.call_number WHERE OLD.id = -1 DO INSTEAD NOTHING;
+CREATE RULE protect_cn_delete AS ON DELETE TO asset.call_number DO INSTEAD UPDATE asset.call_number SET deleted = TRUE WHERE OLD.id = asset.call_number.id RETURNING *;
+CREATE TRIGGER protect_acn_id_neg1
+  BEFORE UPDATE ON asset.call_number
+  FOR EACH ROW WHEN (OLD.id = -1)
+  EXECUTE PROCEDURE evergreen.raise_protected_row_exception();
 
 CREATE TRIGGER asset_label_sortkey_trigger
     BEFORE UPDATE OR INSERT ON asset.call_number
@@ -659,7 +662,7 @@ DECLARE
 BEGIN
     SELECT 1 INTO trans FROM biblio.record_entry b JOIN config.bib_source src ON (b.source = src.id) WHERE src.transcendant AND b.id = rid;
 
-    FOR ans IN SELECT u.id, t.depth FROM actor.org_unit_ancestors(org) AS u JOIN actor.org_unit_type t ON (u.ou_type = t.id) LOOP
+    FOR ans IN SELECT u.id, t.depth FROM actor.org_unit_ancestors(org) AS u JOIN actor.org_unit_type t ON (u.ou_type = t.id) WHERE staff_catalog_visible LOOP
         RETURN QUERY
         WITH available_statuses AS (SELECT ARRAY_AGG(id) AS ids FROM config.copy_status WHERE is_available),
             cp AS(
@@ -752,8 +755,6 @@ $f$ LANGUAGE PLPGSQL;
 
 
 CREATE OR REPLACE FUNCTION asset.record_has_holdable_copy ( rid BIGINT, ou INT DEFAULT NULL) RETURNS BOOL AS $f$
-DECLARE
-    ous INT[] := (SELECT array_agg(id) FROM actor.org_unit_descendants(COALESCE(ou, (SELECT id FROM evergreen.org_top()))));
 BEGIN
     PERFORM 1
         FROM
@@ -768,7 +769,7 @@ BEGIN
             AND ccs.holdable = true
             AND acp.deleted = false
             AND acpl.deleted = false
-            AND acp.circ_lib = ANY(ous)
+            AND acp.circ_lib IN (SELECT id FROM actor.org_unit_descendants(COALESCE($2,(SELECT id FROM evergreen.org_top()))))
         LIMIT 1;
     IF FOUND THEN
         RETURN true;
@@ -1286,5 +1287,49 @@ CREATE TABLE asset.course_module_term_course_map (
     course          INT     NOT NULL REFERENCES asset.course_module_course (id) ON UPDATE CASCADE ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED
 );
 
+CREATE TYPE asset.holdable_part_count AS (id INT, label TEXT, holdable_count BIGINT);
+CREATE OR REPLACE FUNCTION asset.count_holdable_parts_on_record (record_id BIGINT, pickup_lib INT DEFAULT NULL) RETURNS SETOF asset.holdable_part_count AS $func$
+DECLARE 
+    hard_boundary                   INT;
+    orgs_within_hard_boundary       INT[];
+BEGIN
+
+    SELECT value INTO hard_boundary 
+    FROM actor.org_unit_ancestor_setting('circ.hold_boundary.hard', pickup_lib)
+    LIMIT 1;
+
+    IF hard_boundary IS NOT NULL THEN
+        SELECT ARRAY_AGG(id) INTO orgs_within_hard_boundary
+        FROM actor.org_unit_descendants(pickup_lib, hard_boundary);
+    END IF;
+
+    RETURN QUERY 
+    SELECT 
+        bmp.id, 
+        bmp.label, 
+        COUNT(DISTINCT acp.id) AS holdable_count
+    FROM asset.copy_part_map acpm
+        JOIN biblio.monograph_part bmp ON acpm.part = bmp.id
+        JOIN asset.copy acp ON acpm.target_copy = acp.id
+        JOIN asset.call_number acn ON acp.call_number = acn.id
+        JOIN biblio.record_entry bre ON acn.record = bre.id
+        JOIN config.copy_status ccs ON acp.status = ccs.id
+        JOIN asset.copy_location acpl ON acp.location = acpl.id
+    WHERE
+        NOT bmp.deleted
+        AND (NOT acp.deleted AND acp.holdable)
+        AND bre.id = record_id
+        AND ccs.holdable
+        AND acpl.holdable
+        -- Check the circ_lib, but only when given a pickup lib for our hold AND we have hard boundary restrictions
+        AND CASE WHEN orgs_within_hard_boundary IS NOT NULL THEN 
+                acp.circ_lib = ANY(orgs_within_hard_boundary)
+            ELSE TRUE 
+            END
+    GROUP BY 1, 2
+    ORDER BY bmp.label_sortkey ASC;
+END;
+$func$ LANGUAGE plpgsql;
+
 COMMIT;
 
