@@ -180,28 +180,12 @@ function($scope , $window , $location , egCore , egConfirmDialog) {
         $scope.orgselect_combo_names = val;
     });
 
-    egCore.hatch.getItem('eg.search.search_lib').then(function(val) {
-        $scope.search_lib = egCore.org.get(val);
+    egCore.hatch.getItem('ui.staff.grid.density').then(function(val) {
+        $scope.grid_density = val;
     });
-    $scope.handle_search_lib_changed = function(org) {
-        egCore.hatch.setItem('eg.search.search_lib', org.id());
-    };
 
-    egCore.hatch.getItem('eg.search.pref_lib').then(function(val) {
-        $scope.pref_lib = egCore.org.get(val);
-    });
-    $scope.handle_pref_lib_changed = function(org) {
-        egCore.hatch.setItem('eg.search.pref_lib', org.id());
-    };
-
-    $scope.adv_pane = 'advanced'; // default value if not explicitly set
-    egCore.hatch.getItem('eg.search.adv_pane').then(function(val) {
-        $scope.adv_pane = val;
-    });
-    $scope.$watch('adv_pane', function(newVal, oldVal) {
-        if (typeof newVal != 'undefined' && newVal != oldVal) {
-            egCore.hatch.setItem('eg.search.adv_pane', newVal);
-        }
+    egCore.hatch.getItem('ui.staff.disable_links_newtabs').then(function(val) {
+        $scope.disable_links_newtabs = val;
     });
 
     $scope.apply_sound = function() {
@@ -220,6 +204,23 @@ function($scope , $window , $location , egCore , egConfirmDialog) {
         }
     }
 
+    $scope.apply_grid_density = function() {
+        if ($scope.grid_density && ($scope.grid_density === 'compact' || $scope.grid_density === 'wide' )) {
+            egCore.hatch.setItem('ui.staff.grid.density', $scope.grid_density);
+        } else {
+            egCore.hatch.removeItem('ui.staff.grid.density');
+        }
+        console.log("New density: ", $scope.grid_density);
+    }
+
+    $scope.apply_disable_links_newtabs = function() {
+        if ($scope.disable_links_newtabs) {
+            egCore.hatch.setItem('ui.staff.disable_links_newtabs', true);
+        } else {
+            egCore.hatch.removeItem('ui.staff.disable_links_newtabs');
+        }
+    }
+
     $scope.test_audio = function(sound) {
         egCore.audio.play(sound);
     }
